package com.ibm.etools.iseries.examples.dfu.FormJoin2DatabaseFiles;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2000 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This sample will refer to iSeries files in ADTSLAB library. To be able
 * to run the sample, you have to first restore ADTSLAB savf from library
 * QPDA in WebSphere Development Studio product on V5R1M0 or later releases.
 * For early releases, you need to apply the appropriate PTF listed below
 * for the Application Development ToolSet/400 product:
 *
 * iSeries Release		LPP Number		PTF Number
 * V4R2M0				5769PW100		SF63545
 * V4R4M0				5769PW100		SF63703
 *
 * This sample program demonstrates the use of some of the methods
 * in FormManager bean and how to access a database file which 
 * has multiple keys, and how to filter records by setting conditions.
 *
 * This sample creates a GUI form with multiple text fields and buttons.
 * Each text field is associate to a field in the specified database,
 * such that when a record is retrieved from the database, data will be
 * displayed in the text fields properly, and any changes made to the 
 * text fields, will be updated in the database when a update or write
 * action is performed.
 *
 * Functions that you can perform with the example:import javax.swing.*;
 */
import com.ibm.etools.iseries.ui.*;
import com.ibm.as400.access.*;
import javax.swing.*;


public class FormJoin2DatabaseFiles extends javax.swing.JFrame 
		implements java.awt.event.ActionListener, java.awt.event.WindowListener
{
	private static final String join_key[] = {"model", "partship"};

	private JButton bReadNext 		= null;
	private JButton bAdd 			= null;
	private JButton bUpdate 		= null;
	private JButton bDelete 		= null;
	private JButton bCloseFile 		= null;
	private JTextField tCity 		= null;
	private JTextField tCountry		= null;
	private JTextField tInventory 	= null;
	private JTextField tManufact 	= null;
	private JTextField tModel 		= null;
	private JTextField tPartD 		= null;
	private JTextField tPartNo 		= null;
	private JTextField tPartship 	= null;
	private JTextField tAddress 	= null;
	private com.ibm.as400.access.AS400 as400 = null;
	private com.ibm.etools.iseries.ui.FormManager formManager1 = null;
	private com.ibm.etools.iseries.ui.FormManager formManager2 = null;



/**
 * FormJoin2DatabaseFiles constructor.
 */
public FormJoin2DatabaseFiles() 
{
	super("Join 2 Databases in FormManager");
	setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
	setSize(627, 466);
	setContentPane(getJFrameContentPane());
	
}

/**
 * Return the FormManager1 property value.
 * @return com.ibm.etools.iseries.ui.FormManager
 */
private com.ibm.etools.iseries.ui.FormManager getFormManager1() 
{
	if (formManager1 == null) 
	{
		try 
		{
			formManager1 = new FormManager();
			
			// Associate a database with listManager by setting RecordIOManager.
			// Database "PRODDTL" in library "ADTSLAB". By default, the first
			// record format is used, and the database will be opened as keyed
			// access, and in read and write mode.
			formManager1.setRecordIOManager(new RecordIOManager("PRODDTL","ADTSLAB"));
					
		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return formManager1;
}
/**
 * Return the FormManager2 property value.
 * @return com.ibm.etools.iseries.ui.FormManager
 */
private com.ibm.etools.iseries.ui.FormManager getFormManager2() 
{
	if (formManager2 == null) 
	{
		try
		{
			formManager2 = new FormManager();
			
			// Associate a database with listManager by setting RecordIOManager.
			// Database "MODEL" in library "ADTSLAB". By default, the first
			// record format is used, and the database will be opened as keyed
			// access, and in read and write mode.
			formManager2.setRecordIOManager(new RecordIOManager("MODEL","ADTSLAB"));
					
		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return formManager2;
}

private AS400 getAS400()
{
	if (as400 == null)
	{
		as400 = new com.ibm.as400.access.AS400();
	}
	return as400;
}
/**
 * Return the JFrameContentPane property value.
 * @return JPanel
 */
private JPanel getJFrameContentPane() 
{
	JPanel contentPane = new JPanel();
	contentPane.setLayout(null);
	
	JLabel label1 = new JLabel("FILE PRODDTL (Key is PARTNO), MODEL and PARTSHIP are foreign keys to file MODEL");
	label1.setBounds(12, 18, 673, 19);
	label1.setForeground(java.awt.Color.black);
	contentPane.add(label1);
	
	JLabel label2 = new JLabel("PARTNO (primary key)");
	label2.setBounds(12, 45, 169, 23);
	contentPane.add(label2);
		
	tPartNo = new JTextField();
	tPartNo.setName("PARTNO");
	tPartNo.setBounds(195, 45, 193, 23);
	contentPane.add(tPartNo);
	
	JLabel label3 = new JLabel("PARTD");
	label3.setBounds(12, 77, 169, 23);
	contentPane.add(label3);
	
	tPartD = new JTextField();
	tPartD.setName("PARTD");
	tPartD.setBounds(195, 77, 385, 23);
	contentPane.add(tPartD);
	
	JLabel label4 = new JLabel("MODEL (foreign key)");
	label4.setBounds(12, 107, 169, 23);
	contentPane.add(label4);
	
	tModel = new JTextField();
	tModel.setName("MODEL");
	tModel.setBounds(195, 107, 193, 23);
	contentPane.add(tModel);
	
	JLabel label5 = new JLabel("INVENTORY");
	label5.setBounds(12, 138, 169, 23);
	contentPane.add(label5);
	
	tInventory = new JTextField();
	tInventory.setName("INVENTORY");
	tInventory.setBounds(195, 138, 193, 23);
	contentPane.add(tInventory);
	
	JLabel label6 = new JLabel("PARTSHIP (foreign key)");
	label6.setBounds(12, 168, 169, 23);
	contentPane.add(label6);
	
	tPartship = new JTextField();
	tPartship.setName("PARTSHIP");
	tPartship.setBounds(195, 168, 193, 23);
	contentPane.add(tPartship);
	
	JLabel label7 = new JLabel("FILE MODEL (Key is MODEL and PARTSHIP)");
	label7.setBounds(12, 218, 671, 21);
	label7.setForeground(java.awt.Color.black);
	contentPane.add(label7);
	
	JLabel label8 = new JLabel("MANUFACT");
	label8.setBounds(12, 247, 169, 23);
	contentPane.add(label8);
	
	tManufact = new JTextField();
	tManufact.setName("MANUFACT");
	tManufact.setBounds(195, 247, 385, 23);
	contentPane.add(tManufact);
	
	JLabel label9 = new JLabel("ADDRESS");
	label9.setBounds(12, 277, 169, 23);
	contentPane.add(label9);
	
	tAddress = new JTextField();
	tAddress.setName("ADDRESS");
	tAddress.setBounds(195, 277, 385, 23);
	contentPane.add(tAddress);
	
	JLabel label10 = new JLabel("CITY");
	label10.setBounds(12, 311, 169, 23);
	contentPane.add(label10);
	
	tCity = new JTextField();
	tCity.setName("CITY");
	tCity.setBounds(195, 311, 193, 23);
	contentPane.add(tCity);
	
	JLabel label11 = new JLabel("COUNTRY");
	label11.setBounds(12, 342, 169, 23);
	contentPane.add(label11);
	
	tCountry = new JTextField();
	tCountry.setName("COUNTRY");
	tCountry.setBounds(195, 342, 193, 23);
	contentPane.add(tCountry);
	
	bReadNext = new JButton("ReadNext");
	bReadNext.setBounds(25, 387, 95, 27);
	contentPane.add(bReadNext);
	
	bAdd = new JButton("Add");
	bAdd.setBounds(145, 389, 95, 25);
	contentPane.add(bAdd);
	
	bUpdate = new JButton("Update");
	bUpdate.setBounds(265, 389, 95, 25);
	contentPane.add(bUpdate);
			
	bDelete = new JButton("Delete");
	bDelete.setBounds(385, 389, 95, 25);
	contentPane.add(bDelete);
	
	bCloseFile = new JButton("CloseFile");
	bCloseFile.setBounds(505, 389, 95, 25);
	contentPane.add(bCloseFile);
	
	// Use the contentPane as the display container for formManager.
	getFormManager1().setDisplayContainer(contentPane);
	
	// set both form managers referring to the same as400 connection.
	getFormManager1().setSystem(getAS400());
	getFormManager2().setSystem(getAS400());

	
	// Add listeners to all buttons
	bReadNext.addActionListener(this);
	bAdd.addActionListener(this);;
	bUpdate.addActionListener(this);
	bDelete.addActionListener(this);
	bCloseFile.addActionListener(this);
	
	// Add window listener
	this.addWindowListener(this);

	return contentPane;
}
public void actionPerformed(java.awt.event.ActionEvent e) 
{
	Object obj = e.getSource();
	
	try
	{
		if (obj == bReadNext) 
			getFormManager1().readNextRecord();
		if (obj == bAdd) 
			getFormManager1().addRecord();
		if (obj == bUpdate) 
			getFormManager1().updateRecord();
		if (obj == bDelete) 
			getFormManager1().deleteRecord();
		if (obj == bCloseFile) 
			getFormManager1().closeFile();
	}
	catch (Exception ex)
	{
		ex.printStackTrace();
	}
}

public void windowActivated(java.awt.event.WindowEvent e) {};
public void windowClosed(java.awt.event.WindowEvent e) {};
public void windowClosing(java.awt.event.WindowEvent e) {};
public void windowDeactivated(java.awt.event.WindowEvent e) {};
public void windowDeiconified(java.awt.event.WindowEvent e) {};
public void windowIconified(java.awt.event.WindowEvent e) {};
public void windowOpened(java.awt.event.WindowEvent e) 
{
	if (e.getSource() == this) 
	{
		try 
		{
			// Join 2 databases that associate with formManager1 and
			// formManager2 with the keys specified in join_key,
			// i.e. the two databases will be joined with equal value
			// in fields "model" and "partship".
			getFormManager1().joinDataBase(join_key, getFormManager2());
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
		}
	}

}
/**
 * main entrypoint - starts the part when it is run as an application
 * @param args java.lang.String[]
 */
public static void main(java.lang.String[] args) 
{
	try 
	{
		FormJoin2DatabaseFiles aFormJoin2DatabaseFiles;
		aFormJoin2DatabaseFiles = new FormJoin2DatabaseFiles();
		aFormJoin2DatabaseFiles.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				System.exit(0);
			};
		});
		aFormJoin2DatabaseFiles.show();
		aFormJoin2DatabaseFiles.setVisible(true);
	} catch (Throwable exception) 
	{
		System.err.println("Exception occurred in main()");
		exception.printStackTrace(System.out);
	}
}
}
