package com.ibm.etools.iseries.examples.dfu.FormManagerWithFilter;

// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2002 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.
//


/**
 * This sample will refer to iSeries files in ADTSLAB library. To be able
 * to run the sample, you have to first restore ADTSLAB savf from library
 * QPDA in WebSphere Development Studio product on V5R1M0 or later releases.
 * For early releases, you need to apply the appropriate PTF listed below
 * for the Application Development ToolSet/400 product:
 *
 * iSeries Release		LPP Number		PTF Number
 * V4R2M0				5769PW100		SF63545
 * V4R4M0				5769PW100		SF63703
 *
 * This sample program demonstrates the use of some of the methods
 * in FormManager bean and how to access a database file which 
 * has multiple keys, and how to filter records by setting conditions.
 *
 * This sample creates a GUI form with multiple text fields and buttons.
 * Each text field is associate to a field in the specified database,
 * such that when a record is retrieved from the database, data will be
 * displayed in the text fields properly, and any changes made to the 
 * text fields, will be updated in the database when a update or write
 * action is performed.
 *
 * Functions that you can perform with the example:
 * 1) By clicking button "ReadNext", the next record with field BRANCH equals
 * to "12345" is retrieved. If this is first action you perform to the
 * database, a sign on dialog will pop up for server name, user id and 
 * password. If end of file is reached, exception is thrown.
 *
 * 2) By clicking button "ReadPrevious", the previous record with field BRANCH
 * equals to "12345" is retrieved. If top of file is reached, exception is 
 * thrown.
 * 
 * 3) By clicking button "ClearAllData", all the fields in the form will
 * be cleared.
 * 
 * 4) You can type in values in the key fields, Part No, Shipping Date, and
 * Branch, then by clicking button "Read", the record with specified key
 * values will be retrieved and displayed.
 * 
 * 5) Click button "ClearAllData", then click button "CursorFirst" will
 * place the database cursor at the first record with field BRANCH
 * equals to "12345", then click button "Read" will display that record.
 * 
 * 6) Click button "ClearAllData", then click button "CursorLast" will
 * place the database cursor at the last record with field BRANCH
 * equals to "12345", then click button "Read" will display that record.
 * 
 * 7) Click button "CursorNext" will place the database cursor at the
 * next record with field BRANCH equals to "12345".
 * 
 * 8) Click button "CursorPrevious" will place the database cursor at the
 * previous record with field BRANCH equals to "12345".
 * 
 * 9) Fill in the GUI form with values then click button "Add" will create 
 * a new record for you in the database.
 * 
 * 10) By clicking button "Delete" will delete the record where the database
 * cursor is at.
 * 
 * 11) By clicking button "Update" will update the record where the database
 * cursor is at with the values in the GUI form.
 * 
 * 12) By clicking cutton "CloseFile" will close the database file. Any other 
 * actions will automatically open the file if the file is closed.
 * 
 */





import javax.swing.*;
import com.ibm.etools.iseries.ui.FormManager;
import com.ibm.etools.iseries.ui.RecordIOManager;




public class FormManagerWithFilter extends javax.swing.JFrame 
{
	
	private JButton 		buttonReadNext 		= null;
	private JButton 		buttonReadPrev 		= null;
	private JButton 		buttonRead 			= null;
	private JButton 		buttonClearAll 		= null;
	private JButton 		buttonCursorFirst 	= null;
	private JButton 		buttonCursorLast 	= null;
	private JButton 		buttonCursorNext 	= null;
	private JButton 		buttonCursorPrev 	= null;
	private JButton 		buttonAdd 			= null;
	private JButton 		buttonUpdate 		= null;
	private JButton 		buttonDelete 		= null;
	private JButton 		buttonCloseFile 	= null;


	private ButtonListener 	buttonListener 		= new ButtonListener();
	private FormManager 	formMgr				= null;
	private JTextField 		textBranch 			= null;
	private JTextField 		textCountry 		= null;
	private JTextField 		textDest 			= null;
	private JTextField 		textPartNo 			= null;
	private JTextField 		textPartShip	 	= null;
	private JTextField 		textQty 			= null;
	private JTextField 		textTime 			= null;


/**
 * Listener that listens to button clicks.
 */
class ButtonListener implements java.awt.event.ActionListener 
{
	public void actionPerformed(java.awt.event.ActionEvent e) 
	{
		Object obj = e.getSource();
		
		try
		{
			if (obj == buttonReadNext) 
				formMgr.readNextRecord();
			else if (obj == buttonReadPrev) 
				formMgr.readPreviousRecord();
			else if (obj == buttonRead)
				formMgr.readRecord();
			else if (obj == buttonClearAll)
				formMgr.clearAllData();
			else if (obj == buttonCursorFirst)
				formMgr.positionCursorToFirst();
			else if (obj == buttonCursorLast)
				formMgr.positionCursorToLast();
			else if (obj == buttonCursorNext)
				formMgr.positionCursorToNext();
			else if (obj == buttonCursorPrev)
				formMgr.positionCursorToPrevious();
			else if (obj == buttonCloseFile)
				formMgr.closeFile();
			else if (obj == buttonAdd)
				formMgr.addRecord();
			else if (obj == buttonUpdate)
				formMgr.updateRecord();
			else if (obj == buttonDelete)
				formMgr.deleteRecord();
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
		}
	}
}


/**
 * Constructor
 */
public FormManagerWithFilter() 
{
	super();
	setSize(748, 377);
	setTitle("Form with multiple keys");
		
	createContentPane();
	associateGUIFormWithDatabase();

}

/**
 * Create the main panel for this JFrame
 */
private void createContentPane()
{
	JPanel jContentPane = new javax.swing.JPanel();
	jContentPane.setLayout(null);


	JLabel labelPartNo = new JLabel();
	labelPartNo.setText("Part No.:");
	labelPartNo.setBounds(22, 18, 52, 13);
	jContentPane.add(labelPartNo);
	
	// To associate this textPartNo text field with the field PARTNO
	// in the database, we must set the name of this widget to the
	// database field name.
	JTextField textPartNo = new JTextField();
	textPartNo.setName("PARTNO");
	textPartNo.setBounds(85, 13, 142, 23);
	jContentPane.add(textPartNo);
	
	JLabel labelShipDate = new JLabel();
	labelShipDate.setText("Shipping Date:");
	labelShipDate.setBounds(260, 13, 91, 18);
	jContentPane.add(labelShipDate);
	
	// associate textPartShip to field PARTSHIP
	JTextField textPartShip = new JTextField();
	textPartShip.setName("PARTSHIP");
	textPartShip.setBounds(357, 12, 142, 23);
	jContentPane.add(textPartShip);
	
	JLabel labelBranch = new JLabel();
	labelBranch.setText("Branch:");
	labelBranch.setBounds(520, 17, 45, 14);
	jContentPane.add(labelBranch);
	
	// associate textBranch to field BRANCH
	JTextField textBranch = new JTextField();
	textBranch.setName("BRANCH");
	textBranch.setBounds(575, 14, 142, 23);
	jContentPane.add(textBranch);
	
	buttonReadNext = new JButton();
	buttonReadNext.setText("ReadNext");
	buttonReadNext.setBounds(18, 262, 113, 24);
	buttonReadNext.addActionListener(buttonListener);
	jContentPane.add(buttonReadNext);
	
	buttonReadPrev = new JButton();
	buttonReadPrev.setText("ReadPrevious");
	buttonReadPrev.setBounds(142, 262, 113, 24);
	buttonReadPrev.addActionListener(buttonListener);
	jContentPane.add(buttonReadPrev);
	
	buttonRead = new JButton();
	buttonRead.setText("Read");
	buttonRead.setBounds(265, 262, 113, 24);
	buttonRead.addActionListener(buttonListener);
	jContentPane.add(buttonRead);
	
	buttonClearAll = new JButton();
	buttonClearAll.setText("ClearAllData");
	buttonClearAll.setBounds(390, 262, 126, 24);
	buttonClearAll.addActionListener(buttonListener);
	jContentPane.add(buttonClearAll);
	
	buttonCursorFirst = new JButton();
	buttonCursorFirst.setText("CursorFirst");
	buttonCursorFirst.setBounds(17, 294, 113, 24);
	buttonCursorFirst.addActionListener(buttonListener);
	jContentPane.add(buttonCursorFirst);
	
	buttonCursorLast = new JButton();
	buttonCursorLast.setText("CursorLast");
	buttonCursorLast.setBounds(142, 294, 113, 24);
	buttonCursorLast.addActionListener(buttonListener);
	jContentPane.add(buttonCursorLast);
	
	buttonCursorNext = new JButton();
	buttonCursorNext.setText("CursorNext");
	buttonCursorNext.setBounds(265, 294, 113, 24);
	buttonCursorNext.addActionListener(buttonListener);
	jContentPane.add(buttonCursorNext);
	
	buttonCursorPrev = new JButton();
	buttonCursorPrev.setText("CursorPrevious");
	buttonCursorPrev.setBounds(390, 294, 126, 24);
	buttonCursorPrev.addActionListener(buttonListener);
	jContentPane.add(buttonCursorPrev);
	
	buttonAdd = new JButton();
	buttonAdd.setText("Add");
	buttonAdd.setBounds(588, 77, 89, 27);
	buttonAdd.addActionListener(buttonListener);
	jContentPane.add(buttonAdd);
	
	buttonUpdate = new JButton();
	buttonUpdate.setText("Update");
	buttonUpdate.setBounds(588, 120, 89, 27);
	buttonUpdate.addActionListener(buttonListener);
	jContentPane.add(buttonUpdate);
	
	buttonDelete = new JButton();
	buttonDelete.setText("Delete");
	buttonDelete.setBounds(588, 167, 89, 27);
	buttonDelete.addActionListener(buttonListener);
	jContentPane.add(buttonDelete);
	
	buttonCloseFile = new JButton();
	buttonCloseFile.setText("CloseFile");
	buttonCloseFile.setBounds(588, 212, 89, 27);
	buttonCloseFile.addActionListener(buttonListener);
	jContentPane.add(buttonCloseFile);
	
	// Detail Pane
	JPanel detailPane = new JPanel();
	detailPane.setLayout(null);
	detailPane.setBounds(16, 58, 553, 190);
	
	JLabel labelDest = new javax.swing.JLabel();
	labelDest.setText("Destination:");
	labelDest.setBounds(21, 25, 73, 17);
	detailPane.add(labelDest);


	JLabel labelQty = new JLabel();
	labelQty.setText("Quantity:");
	labelQty.setBounds(21, 66, 73, 17);
	detailPane.add(labelQty);
	
	JLabel labelTime = new JLabel();
	labelTime.setText("Time:");
	labelTime.setBounds(21, 107, 73, 17);
	detailPane.add(labelTime);
	
	JLabel labelCountry = new JLabel();
	labelCountry.setText("Country:");
	labelCountry.setBounds(21, 148, 73, 17);
	detailPane.add(labelCountry);
	
	// associate textDest to field DESTINATN
	JTextField textDest = new JTextField();
	textDest.setName("DESTINATN");
	textDest.setBounds(109, 22, 376, 20);
	detailPane.add(textDest);
	
	// associate textQty to field QTY
	JTextField textQty = new JTextField();
	textQty.setName("QTY");
	textQty.setBounds(109, 64, 201, 20);
	detailPane.add(textQty);
	
	// associate textTime to field TIME_T
	JTextField textTime = new JTextField();
	textTime.setName("TIME_T");
	textTime.setBounds(109, 106, 201, 20);
	detailPane.add(textTime);
	
	// associate textCountry to field COUNTRY
	JTextField textCountry = new JTextField();
	textCountry.setName("COUNTRY");
	textCountry.setBounds(109, 148, 201, 19);	
	detailPane.add(textCountry);
	
	jContentPane.add(detailPane);


	setContentPane(jContentPane);
}

/**
 * Associate this GUI form JFrame with a database
 */
private void associateGUIFormWithDatabase()
{
	formMgr = new FormManager();


	try
	{		
		// Define to use database "MULTKEYS" in library "ADTSLAB".
		// By default, if record format is not set, the first record
		// format in the database will be used. The database will be
		// opened as read and write, and accessed by keys.
		RecordIOManager recIOMgr = new RecordIOManager("MULTKEYS","ADTSLAB");
				
		// If you want to set a filter to the database, define
		// a condtion class. 
		// Set the condition class name. This condition class
		// must extends com.ibm.etools.iseries.ui.AbstractCondition,
		// and must implement method isConditionValid(com.ibm.as400.access.Record)
		// You can try to remove the next two statements 
		// (setCheckConditionClassName and setCheckConditionPackageName)
		// and see the difference between with filters and without
		// filters.
		recIOMgr.setCheckConditionClassName("FilterBranchEQ12345");
		
		// set the package name of the condition class
		recIOMgr.setCheckConditionPackageName("com.ibm.etools.iseries.examples.dfu.FormManagerWithFilter");	
		
		// Associate formMgr with recIOMgr.
		formMgr.setRecordIOManager(recIOMgr);		
		
	}
	catch (Exception e)
	{
		e.printStackTrace();
	}
	
	// if you are only interesting in a subset of records in the 
	// database, you can set a condition to filter the records
	
	
	// assoicate this GUI form with formMgr
	formMgr.setDisplayContainer(this);


}




public static void main(java.lang.String[] args) 
{
	try 
	{
		FormManagerWithFilter aMultipleKeysForm = new FormManagerWithFilter();
		aMultipleKeysForm.addWindowListener(new java.awt.event.WindowAdapter() 
		{
			public void windowClosing(java.awt.event.WindowEvent e) {
				System.exit(0);
			};
		});
		aMultipleKeysForm.show();
		aMultipleKeysForm.setVisible(true);
	} 
	catch (Throwable exception) 
	{
		System.err.println("Exception occurred in main()");
		exception.printStackTrace(System.out);
	}
}


}
