package com.ibm.etools.iseries.examples.dfu.ListManagerSample2;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2002 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This sample will refer to iSeries files in ADTSLAB library. To be able
 * to run the sample, you have to first restore ADTSLAB savf from library
 * QPDA in WebSphere Development Studio product on V5R1M0 or later releases.
 * For early releases, you need to apply the appropriate PTF listed below
 * for the Application Development ToolSet/400 product:
 *
 * iSeries Release		LPP Number		PTF Number
 * V4R2M0				5769PW100		SF63545
 * V4R4M0				5769PW100		SF63703
 *
 *
 * This sample program demonstrates the use of ListManager.
 *
 * This sample creates a GUI with a JFormattedTable and some buttons.
 * Each button demonstrates a method function of ListManager.
 * The table is associate to a specified database, such that when
 * a button is pressed, a action is performed to the database.
 *
 * Functions that you can perform with the example:
 * 1) By clicking button "readAll", it will invoke method
 * readAllRecords() of class ListManager and all the records 
 * from the database are displayed.
 * 
 * 2) If there are a too many records in the database, and if it takes too
 * long to display all the records, you can press button "CancelReadAll",
 * which will cancel the action of readAllRecords().
 * 
 * 3) Instead of retrieving all the records, you can select to retrieve a
 * subset of records by clicking button "ReadNextSet" or "ReadPreviousSet",
 * which will call method readNextSetOfRecords() and 
 * readPreviousSetOfRecords(). In this sample, the number of records
 * will be read at a time is set to 10, when class RecordIOManager is
 * instantiated.
 * 
 * 4) You can make changes directly to any data in the table, and by 
 * clicking on another row, the changes is updated automatically, or
 * you can click on button "Update" which will explicitly update the 
 * current row.
 * 
 * 5) By clicking button "Delete", the current row is deleted from
 * database.
 * 
 * 6) By clicking button "InsertBefore", a new row is added before
 * the current row, and you can type in new values for the new row.
 * When a different row is selected, the new row is added to the 
 * database.
 * 
 * 7) By clicking button "InsertAfter", a new row is added after 
 * the current row, and you can type in new values for the new row.
 * When a different row is selected, the new row is added to the 
 * database.
 * 
 * 8) By clicking button "Ascending", the records will be retrieved in
 * ascending order by keys.
 * 
 * 9) By clicking button "Descending", the records will be retrieved in
 * descending order by keys.
 * 
 * 10) By clicking button "Commit", transactions will be commited to the
 * database.
 * 
 * 11) By clicking button "Rollback", transactions will be rolled back, and
 * none of the transaction will be updated from the last commit.
 * 
 * 12) By clicking button "CloseFile", database file is closed, and the 
 * table that is associated to the database is cleared.
 * 
 * 13) By clicking button "ClearAllData", table is cleared.
 * 
 */

import javax.swing.*;
import com.ibm.etools.iseries.ui.*;

public class ListManagerSample2 extends JFrame implements java.awt.event.ActionListener
{
	private JButton bDescending = null;
	private JButton bCommit  = null;
	private JButton bReadAll  = null;
	private JButton bCancelReadAll  = null;
	private JButton bReadNextSet  = null;
	private JButton bReadPreviousSet  = null;
	private JButton bClearAllData  = null;
	private JButton bUpdate  = null;
	private JButton bDelete  = null;
	private JButton bInsertBefore  = null;
	private JButton bInsertAfter  = null;
	private JButton bRollback  = null;
	private JButton bCloseFile  = null;
	private JButton bAscending  = null;
	private ListManager listManager = null;
	private JFormattedTable table = null;


public void actionPerformed(java.awt.event.ActionEvent e) 
{
	Object obj = e.getSource();
	
	try
	{
		if (obj == bDescending) 
		{
			getListManager().setAscendingOrder(false);
			bDescending.setEnabled(false);
			bAscending.setEnabled(true);
		}
		else if (obj == bCommit) 
			getListManager().commit();
		else if (obj == bReadAll) 
			getListManager().readAllRecords();
		else if (obj == bCancelReadAll) 
			getListManager().cancelReadAllRecords();
		else if (obj == bReadNextSet) 
			getListManager().readNextSetOfRecords();
		else if (obj == bReadPreviousSet) 
			getListManager().readPreviousSetOfRecords();
		else if (obj == bClearAllData) 
			getListManager().clearAllData();
		else if (obj == bUpdate) 
			getListManager().updateRecord(table.getSelectedRow());
		else if (obj == bDelete) 
			getListManager().deleteSelectedRecords();
		else if (obj == bInsertBefore) 
			getListManager().insertBeforeCurrentRecord();
		else if (obj == bInsertAfter) 
			getListManager().insertAfterCurrentRecord();
		else if (obj == bRollback) 
			getListManager().rollback();
		else if (obj == bCloseFile) 
			getListManager().closeFile();
		else if (obj == bAscending) 
		{
			getListManager().setAscendingOrder(true);
			bDescending.setEnabled(true);
			bAscending.setEnabled(false);
		}
	}
	catch (Exception ex)
	{
		ex.printStackTrace();
	}
}
/**
 * ListManagerSample2 constructor comment.
 */
public ListManagerSample2() {
	super("ListManager Sample 2");
	setSize(716, 381);
	setContentPane(getJFrameContentPane());
	
}
/**
 * Return the JFrameContentPane property value.
 * @return JPanel
 */
private JPanel getJFrameContentPane() 
{
	JPanel contentPane = new JPanel();
	contentPane.setLayout(null);

	table = new JFormattedTable();
	table.setBounds(0, 0, 200, 200);
	JScrollPane scrollPane = new JScrollPane();
	scrollPane.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
	scrollPane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);
	scrollPane.setBounds(22, 26, 545, 232);
	scrollPane.setViewportView(table);
	scrollPane.setColumnHeaderView(table.getTableHeader());
	contentPane.add(scrollPane);

	bDescending = new JButton("Descending");
	bDescending.setBounds(585, 93, 111, 26);
	contentPane.add(bDescending);
			
	bCommit = new JButton("Commit");
	bCommit.setBounds(585, 136, 111, 26);
	contentPane.add(bCommit);
			
	bReadAll = new JButton("ReadAll");
	bReadAll.setBounds(23, 270, 85, 27);
	contentPane.add(bReadAll);
			
	bCancelReadAll = new JButton("CancelReadAll");
	bCancelReadAll.setBounds(114, 270, 122, 27);
	contentPane.add(bCancelReadAll);
			
	bReadNextSet = new JButton("ReadNextSet");
	bReadNextSet.setBounds(245, 270, 109, 27);
	contentPane.add(bReadNextSet);
			
	bReadPreviousSet = new JButton("ReadPreviousSet");
	bReadPreviousSet.setBounds(361, 270, 140, 27);
	contentPane.add(bReadPreviousSet);
			
	bClearAllData = new JButton("ClearAllData");
	bClearAllData.setBounds(507, 305, 108, 27);
	contentPane.add(bClearAllData);
			
	bUpdate = new JButton("Update");
	bUpdate.setBounds(23, 305, 85, 27);
	contentPane.add(bUpdate);
			
	bDelete = new JButton("Delete");
	bDelete.setBounds(114, 305, 122, 27);
	contentPane.add(bDelete);
			
	bInsertBefore = new JButton("InsertBefore");
	bInsertBefore.setBounds(245, 305, 109, 27);
	contentPane.add(bInsertBefore);
			
	bInsertAfter = new JButton("InsertAfter");
	bInsertAfter.setBounds(361, 305, 140, 27);
	contentPane.add(bInsertAfter);
			
	bRollback = new JButton("Rollback");
	bRollback.setBounds(585, 176, 111, 26);
	contentPane.add(bRollback);
			
	bCloseFile = new JButton("CloseFile");
	bCloseFile.setBounds(507, 270, 108, 27);
	contentPane.add(bCloseFile);
	
	bAscending = new JButton("Ascending");
	bAscending.setBounds(585, 52, 111, 26);
	bAscending.setEnabled(false);
	contentPane.add(bAscending);
			
	// Add listeners to all buttons
	bDescending.addActionListener(this);
	bCommit.addActionListener(this);
	bReadAll.addActionListener(this);
	bCancelReadAll.addActionListener(this);
	bReadNextSet.addActionListener(this);
	bReadPreviousSet.addActionListener(this);
	bClearAllData.addActionListener(this);
	bUpdate.addActionListener(this);
	bDelete.addActionListener(this);
	bInsertBefore.addActionListener(this);
	bInsertAfter.addActionListener(this);
	bRollback.addActionListener(this);
	bCloseFile.addActionListener(this);
	bAscending.addActionListener(this);

	getListManager().setDisplayContainer(scrollPane);

	return contentPane;
}

private ListManager getListManager()
{
	if (listManager == null)
	{
		// instantiate list manager
		listManager = new ListManager();


		try
		{
			// Associate a database with listManager by setting RecordIOManager.
			// Database is "PRODDTL" in library "ADTSLAB". 
			// The database will be keyed access, and is opened as read and write;
			// with commitment control, the journal is JRN1 in library ADTSLAB.
			listManager.setRecordIOManager(new RecordIOManager(
				"","","","PRODDTL","ADTSLAB",
				RecordIOManager.FILEACCESS_KEYED,
				RecordIOManager.OPENTYPE_READ_WRITE, 10,
				RecordIOManager.COMMITLOCKLEVEL_CHANGE, "JRN1","ADTSLAB"));
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}
	
	return listManager;
}
/**
 * main entrypoint - starts the part when it is run as an application
 * @param args java.lang.String[]
 */
public static void main(java.lang.String[] args) {
	try {
		ListManagerSample2 aListManagerSample2;
		aListManagerSample2 = new ListManagerSample2();
		aListManagerSample2.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				System.exit(0);
			};
		});
		aListManagerSample2.setVisible(true);
	} catch (Throwable exception) {
		System.err.println("Exception occurred in main()");
		exception.printStackTrace(System.out);
	}
}
}
