package com.ibm.etools.iseries.examples.jformatted.JFormattedComboBoxLabelSample;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2000 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.
//
/**
 * This sample program demonstrates the use of JFormattedComboBox
 * and JFormattedLabel.
 *
 * Functions that you can perform with the example:
 * 1) In the sample, the field with label "JFormattedTextField:" is 
 * configured to only accept numeric value, and is limited to length 
 * of 8. Enter a value in the field, then press tab to move to 
 * the next field, the value is automatically formatted. When button
 * AddItem is clicked, the value in JFormattedTextField is added to 
 * JFormattedComboBox. When an item is selected from the 
 * JFormattedComboBox, the selected item is set to JFormattedLabel and
 * JLabel. 
 * 
 * 2) The blue JFormattedComboBox is editable and is configure to only 
 * accept numeric values with length of 10, decimal places of 2, 
 * e.g. 12345678.99. After entering a value in the combo box, press 
 * tab will format the value for you. By clicking button SetValues will 
 * set a list of values to the combo box, and each value is formatted.
 * When an item is selected in the JFormattedComboBox, the selected item 
 * is set to JFormattedLabel, JLabelA and JLabelB using different get 
 * methods.
 * 
 */

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextArea;

import com.ibm.etools.iseries.ui.AS400FieldModel;
import com.ibm.etools.iseries.ui.DataAttributes;
import com.ibm.etools.iseries.ui.EditcodeEditwordFormatter;
import com.ibm.etools.iseries.ui.JFormattedComboBox;
import com.ibm.etools.iseries.ui.JFormattedLabel;
import com.ibm.etools.iseries.ui.JFormattedTextField;
import com.ibm.etools.iseries.ui.MetalFormattedComboBoxEditor;

public class JFormattedComboBoxLabelSample extends javax.swing.JFrame 
		implements java.awt.event.ActionListener, java.awt.event.ItemListener 
{
	private static final String values [] = {"123456.78", "-12345.67", "12345678.99", "0", "123"};

	private com.ibm.etools.iseries.ui.JFormattedComboBox 	fcombo1 	= null;
	private com.ibm.etools.iseries.ui.JFormattedLabel 		flabel1 	= null;
	private com.ibm.etools.iseries.ui.JFormattedTextField 	ftext1 		= null;
	private com.ibm.etools.iseries.ui.JFormattedComboBox 	fcombo2 	= null;
	private com.ibm.etools.iseries.ui.JFormattedLabel 		flabel2 	= null;
	private JLabel labelOutput1 	= null;
	private JLabel labelOutput2 	= null;
	private JLabel labelOutput3 	= null;
	private JButton bAddItem 		= null;
	private JButton	bRemoveItemAt 	= null;
	private JButton bRemoveAllItems = null;
	private JButton bSetValues 		= null;
	private JButton bRemoveAllItems2 = null;


/**
 * Constructor.
 */
public JFormattedComboBoxLabelSample() {
	super("JFormattedComboBox & JFormattedLabel Sample");
	setSize(755, 456);
	setContentPane(getJFrameContentPane());
}
/**
 * Return the AS400FieldModel property value.
 * @return com.ibm.etools.iseries.ui.AS400FieldModel
 */
private com.ibm.etools.iseries.ui.AS400FieldModel getAS400FieldModel1() 
{
	AS400FieldModel fieldModel = null;
	try
	{
		DataAttributes attr = new com.ibm.etools.iseries.ui.DataAttributes(DataAttributes.DATATYPE_NUMERIC, 8);
		EditcodeEditwordFormatter formatter = new com.ibm.etools.iseries.ui.EditcodeEditwordFormatter();
		formatter.setEditCode('Y');
		fieldModel = new com.ibm.etools.iseries.ui.AS400FieldModel(attr, formatter);
	}
	catch (Exception e)
	{
		e.printStackTrace();
	}
	return fieldModel;
}
/**
 * Return the AS400FieldModel property value.
 * @return com.ibm.etools.iseries.ui.AS400FieldModel
 */
private com.ibm.etools.iseries.ui.AS400FieldModel getAS400FieldModel2()
{
	AS400FieldModel fieldModel = null;
	try 
	{
		DataAttributes attr = new com.ibm.etools.iseries.ui.DataAttributes(DataAttributes.DATATYPE_NUMERIC, 10, 2, '.');
		EditcodeEditwordFormatter formatter = new com.ibm.etools.iseries.ui.EditcodeEditwordFormatter();
		formatter.setEditCode('1');
		formatter.setEditCodeParmType(EditcodeEditwordFormatter.EDITCODEPARM_CURRENCY);
		fieldModel = new com.ibm.etools.iseries.ui.AS400FieldModel(attr, formatter);
	}
	catch (java.lang.Throwable e)
	{
		e.printStackTrace();
	}

	return fieldModel;
}
/**
 * Return the JFrameContentPane property value.
 * @return javax.swing.JPanel
 */
private javax.swing.JPanel getJFrameContentPane() 
{
	JPanel contentPane = new javax.swing.JPanel();
	contentPane.setLayout(null);
	
	JTextArea textArea1 = new JTextArea();
	textArea1.setText("All 3 beans use the same FieldModel (Numeric, length 8, decimalPlaces 0, editcode \'Y\')\nWhen AddItem button is pressed, the value of JFormattedTextField is retrieved using the getUnformattedText method and added to\nJFormattedComboBox. Once an item is selected, the item is retrieved by using getSelectedItem method, which is in an unformatted \nform and is displayed on both JLabel and JFormattedLabel. Then JFormattedLabel reformats it using setUnformattedText method.");
	textArea1.setBackground(new java.awt.Color(204,204,204));
	textArea1.setBounds(13, 40, 732, 73);
	contentPane.add(textArea1);
	
	JLabel label1 = new JLabel("JFormattedTextField:");
	label1.setBounds(15, 114, 134, 14);
	contentPane.add(label1);

	JLabel label2 = new JLabel("JFormattedComboBox:");
	label2.setBounds(208, 114, 134, 14);
	contentPane.add(label2);
	
	JLabel label3 = new JLabel("JFormattedLabel:");
	label3.setBounds(406, 114, 134, 14);
	contentPane.add(label3);
	
	JLabel label4 = new JLabel("JLabel:");
	label4.setBounds(590, 114, 134, 14);
	contentPane.add(label4);
	
	ftext1 = new JFormattedTextField();
	ftext1.setFieldModel(getAS400FieldModel1());
	ftext1.setBounds(15, 134, 148, 24);
	contentPane.add(ftext1);
	
	fcombo1 = new JFormattedComboBox();
	fcombo1.setFieldModel(getAS400FieldModel1());
	fcombo1.setBounds(207, 134, 148, 24);
	contentPane.add(fcombo1);
	
	flabel1 = new JFormattedLabel();
	flabel1.setBorder(new javax.swing.border.EtchedBorder());
	flabel1.setFieldModel(getAS400FieldModel1());
	flabel1.setBounds(406, 134, 148, 24);
	contentPane.add(flabel1);
	
	labelOutput1 = new JLabel();
	labelOutput1.setBorder(new javax.swing.border.EtchedBorder());
	labelOutput1.setBounds(590, 134, 148, 24);
	contentPane.add(labelOutput1);
	
	bAddItem = new JButton("AddItem");
	bAddItem.setBounds(16, 171, 105, 24);
	contentPane.add(bAddItem);
	
	bRemoveItemAt = new JButton("RemoveItemAt(0)");
	bRemoveItemAt.setBounds(131, 171, 133, 24);
	contentPane.add(bRemoveItemAt);
	
	bRemoveAllItems = new JButton("RemoveAllItems");
	bRemoveAllItems.setBounds(272, 171, 133, 24);
	contentPane.add(bRemoveAllItems);
	
	JTextArea textArea2 = new JTextArea();
	textArea2.setText("Both JFormattedComboBox and JFormattedLabel use the same FieldModel (Numeric, length 10, decimalPlaces 2, editcode \'1\', \neditcodeParmType is Currency). JFormattedComboBox is an editable field, its foreground and background color is changed\nin formattedComboBoxEditor. When an item is selected, JLabel A is set by the value of getSelectedItemFormattedValue(), and\nJLabel B is set by the value of getSelectedItemInternalValue() and JFormattedLabel is set by the value of getSelectedItem().\nWhen SetValues is pressed, a list of values are added to the comboBox.");
	textArea2.setBackground(new java.awt.Color(204,204,204));
	textArea2.setBounds(13, 212, 727, 89);
	contentPane.add(textArea2);

	JLabel label6 = new JLabel("JFormattedComboBox:");
	label6.setBounds(21, 312, 146, 15);
	contentPane.add(label6);
	
	JLabel label7 = new JLabel("JFormattedLabel");
	label7.setBounds(218, 312, 146, 15);
	contentPane.add(label7);
	
	JLabel label8 = new JLabel("JLabel A:");
	label8.setBounds(410, 312, 146, 15);
	contentPane.add(label8);
	
	JLabel label9 = new JLabel("JLabel B:");
	label9.setBounds(593, 312, 146, 15);
	contentPane.add(label9);
	
	MetalFormattedComboBoxEditor comboBoxEditor = new com.ibm.etools.iseries.ui.MetalFormattedComboBoxEditor();
	comboBoxEditor.setForegroundColor(java.awt.Color.blue);
	comboBoxEditor.setBackgroundColor(java.awt.Color.cyan);
	fcombo2 = new com.ibm.etools.iseries.ui.JFormattedComboBox();
	fcombo2.setBounds(21, 336, 148, 24);
	fcombo2.setEditable(true);
	fcombo2.setFormattedComboBoxEditor(comboBoxEditor);
	fcombo2.setFieldModel(getAS400FieldModel2());
	contentPane.add(fcombo2);
	
	flabel2 = new com.ibm.etools.iseries.ui.JFormattedLabel();
	flabel2.setBorder(new javax.swing.border.EtchedBorder());
	flabel2.setFieldModel(getAS400FieldModel2());
	flabel2.setBounds(218, 335, 148, 24);
	contentPane.add(flabel2);
	
	labelOutput2 = new JLabel();
	labelOutput2.setBorder(new javax.swing.border.EtchedBorder());
	labelOutput2.setBounds(410, 335, 148, 24);
	contentPane.add(labelOutput2);
	
	labelOutput3 = new JLabel();
	labelOutput3.setBorder(new javax.swing.border.EtchedBorder());
	labelOutput3.setBounds(593, 335, 148, 24);
	contentPane.add(labelOutput3);
	
	bSetValues = new JButton("SetValues");
	bSetValues.setBounds(20, 375, 125, 27);
	contentPane.add(bSetValues);
	
	bRemoveAllItems2 = new JButton("RemoveAllItems");
	bRemoveAllItems2.setBounds(163, 376, 150, 26);
	contentPane.add(bRemoveAllItems2);

	// add listeners to buttons and comboBox	
	bAddItem.addActionListener(this);
	bRemoveItemAt.addActionListener(this);
	bRemoveAllItems.addActionListener(this);
	bSetValues.addActionListener(this);
	bRemoveAllItems2.addActionListener(this);
	fcombo1.addItemListener(this);
	fcombo2.addItemListener(this);
	

	return contentPane;
}

/**
 * main entrypoint - starts the part when it is run as an application
 * @param args java.lang.String[]
 */
public static void main(java.lang.String[] args) {
	try {
		JFormattedComboBoxLabelSample aJFormattedComboBoxLabelSample;
		aJFormattedComboBoxLabelSample = new JFormattedComboBoxLabelSample();
		aJFormattedComboBoxLabelSample.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				System.exit(0);
			};
		});
		aJFormattedComboBoxLabelSample.show();
		aJFormattedComboBoxLabelSample.setVisible(true);
	} catch (Throwable exception) {
		System.err.println("Exception occurred in main()");
		exception.printStackTrace(System.out);
	}
}


public void actionPerformed(java.awt.event.ActionEvent e) 
{
	Object obj = e.getSource();
	
	try
	{	
		if (obj == bAddItem) 
		{
			fcombo1.addItem(ftext1.getUnformattedText());
			fcombo1.repaint();
		}
		else if (obj == bRemoveItemAt) 
		{
			fcombo1.removeItemAt(0);
			fcombo1.repaint();
		}
		else if (obj == bRemoveAllItems) 
		{
			fcombo1.removeAllItems();
			fcombo1.repaint();
		}
		else if (obj == bSetValues) 
		{
			fcombo2.setValues(values);
		}
		else if (obj == bRemoveAllItems2) 
		{
			fcombo2.removeAllItems();
			fcombo2.repaint();
		}
	}
	catch (Exception ex)
	{
		ex.printStackTrace();
	}
}
public void itemStateChanged(java.awt.event.ItemEvent e) 
{
	Object obj = e.getSource();
		
	try
	{
		if (obj == fcombo1) 
		{
			flabel1.setUnformattedText((String)fcombo1.getSelectedItem());
			labelOutput1.setText((String)fcombo1.getSelectedItem());
		}
		else if (obj == fcombo2) 
		{
			labelOutput2.setText((String)fcombo2.getSelectedItemFormattedValue());
			labelOutput3.setText((String)fcombo2.getSelectedItemInternalValue());
			flabel2.setUnformattedText((String)fcombo2.getSelectedItem());
		}
	}
	catch (Exception ex)
	{
		ex.printStackTrace();
	}
}

}
