package com.ibm.etools.iseries.examples.jformatted.JFormattedTextFieldEquity;

// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2002 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This sample program demonstrates the use of 
 * com.ibm.etools.iseries.ui.JFormattedTextField. 
 *
 * Functions that you can perform with the example:
 * 1) Enter a 5 character value in field "Symbol". Notice that you cannot 
 * enter more than 5 characters in the field. If you enter a value which
 * is out of the range "A" to "ZZZZZ", e.g. "1B", and when you tab on the 
 * field to go to the next field, the field is turned red and an error 
 * message is displayed.
 * 
 * 2) Enter a number in field "Price". The number cannot exceed
 * 99999.99. Once you press tab to go to the next field, the field is
 * formatted with edit code 'A' and with curreny symbol.
 * 
 * 3) Enter a number in field "Quantity". The number cannot exceed 
 * 99999, and it does not accept decimal values. Once you press tab to
 * go to the next field, the field is formatted with edit code 'A'.
 * 
 * 4) Enter a number in field "Account No.". Notice that the field
 * is already preset with a format, and it only accepts numeric
 * characters.
 * 
 * 5) Enter any characters in field "Password". This field is just using 
 * the regular Swing JPasswordField.
 * 
 * 6) Enter a number in field "Contact Phone". Notice that the field
 * is already preset with a format, and it only accepts numeric characters.
 * 
 */

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JPasswordField;

import com.ibm.etools.iseries.ui.AS400FieldModel;
import com.ibm.etools.iseries.ui.ComparisonRangeValidator;
import com.ibm.etools.iseries.ui.DataAttributes;
import com.ibm.etools.iseries.ui.EditcodeEditwordFormatter;
import com.ibm.etools.iseries.ui.EditmaskAttributes;
import com.ibm.etools.iseries.ui.JFormattedTextField;

public class JFormattedTextFieldEquity extends javax.swing.JFrame 
		implements java.awt.event.FocusListener
{
	private JFormattedTextField jftSymbol 	= null;
	private JFormattedTextField jftPrice 	= null;
	private JFormattedTextField jftQuantity = null;
	private JFormattedTextField jftAccount	= null;
	private JFormattedTextField jftPhone 	= null;
	private DataAttributes		attributes1 = null;
	private JPasswordField      jPassword 	= null;
	private JLabel				labelStatus = null;
	
/**
 * JFormattedBeansEquity constructor.
 */
public JFormattedTextFieldEquity() 
{
	super("EQUITY ORDER ENTRY");
	setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
	setSize(350, 430);
	setContentPane(getJFrameContentPane());
}

public void focusGained (java.awt.event.FocusEvent e) 
{
}
public void focusLost (java.awt.event.FocusEvent e) 
{
	// if the background color of the field is turned red, that means
	// the entry is invalid
	if (jftSymbol.getBackground() == attributes1.getReverseImageColor() )
	{
		labelStatus.setText("Error: Symbol must be in range from 'A' to 'ZZZZZ'.");
	}
	// else no errors occurred, clear the status line
	else 
	{
		labelStatus.setText("");
	}
}
/**
 * Return the JFrameContentPane property value.
 * @return javax.swing.JPanel
 */
private javax.swing.JPanel getJFrameContentPane() 
{
	JPanel contentPane = new JPanel();
	try 
	{
		contentPane.setLayout(null);
		JLabel label1 = new JLabel("Action:");
		label1.setBounds(28, 28, 105, 17);
		contentPane.add(label1);

		JLabel label2 = new JLabel("Symbol:");
		label2.setBounds(28, 77, 105, 17);
		contentPane.add(label2);
		
		JLabel label3 = new JLabel("Price:");
		label3.setBounds(28, 124, 105, 17);
		contentPane.add(label3);
		
		JLabel label4 = new JLabel("Quantity:");
		label4.setBounds(28, 171, 105, 17);
		contentPane.add(label4);
		
		JLabel label5 = new JLabel("Account No.:");
		label5.setBounds(28, 218, 105, 17);
		contentPane.add(label5);
		
		JLabel label6 = new JLabel("Password:");
		label6.setBounds(28, 265, 105, 17);
		contentPane.add(label6);
		
		JLabel label7 = new JLabel("Contact Phone:");
		label7.setBounds(28, 312, 105, 17);
		contentPane.add(label7);
		
		labelStatus = new JLabel("");
		labelStatus.setBounds(28, 345, 300, 17);
		contentPane.add(labelStatus);
		
		JLabel label8 = new JLabel("BUY");
		label8.setBounds(143, 28, 104, 17);
		contentPane.add(label8);
		
		// Symbol is a character field, length of 5, valid range of value is
		// "A" to "ZZZZZ". Characters will be converted to uppercase.
		attributes1 = new DataAttributes(DataAttributes.DATATYPE_CHARACTER, 5);
		ComparisonRangeValidator validator1 = new com.ibm.etools.iseries.ui.ComparisonRangeValidator();
		validator1.setValidityCheckType(ComparisonRangeValidator.VALIDITYTYPE_RANGE);
		validator1.setMinimumRange("A");
		validator1.setMaximumRange("ZZZZZ");
		AS400FieldModel fldModel1 = new AS400FieldModel(attributes1);
		fldModel1.setKeystrokeVerifier(new com.ibm.etools.iseries.ui.UpperCaseDocument());
		fldModel1.setValidator(validator1);
		jftSymbol = new JFormattedTextField(fldModel1);
		jftSymbol.setBounds(143, 73, 104, 25);
		contentPane.add(jftSymbol);
		
		jftSymbol.addFocusListener(this);
		
		// Price is numeric field, length of 6 with decimal places of 2.
		// Edit code is 'A', edit code parameter type is currency.
		DataAttributes attributes2 = new com.ibm.etools.iseries.ui.DataAttributes(DataAttributes.DATATYPE_NUMERIC, 7, 2, '.');
		EditcodeEditwordFormatter formatter2 = new com.ibm.etools.iseries.ui.EditcodeEditwordFormatter(); 
		formatter2.setEditCode('A');
		formatter2.setEditCodeParmType(EditcodeEditwordFormatter.EDITCODEPARM_CURRENCY);
		AS400FieldModel fldModel2 = new com.ibm.etools.iseries.ui.AS400FieldModel(attributes2, formatter2);
		jftPrice = new com.ibm.etools.iseries.ui.JFormattedTextField(fldModel2);
		jftPrice.setBounds(143, 121, 104, 25);
		contentPane.add(jftPrice);
		
		// Quantity is numeric field, length of 5 with no decimal places.
		// Edit code is 'A'.
		jftQuantity = new JFormattedTextField();
		DataAttributes attributes3 = new com.ibm.etools.iseries.ui.DataAttributes(DataAttributes.DATATYPE_NUMERIC, 5);
		EditcodeEditwordFormatter formatter3 = new com.ibm.etools.iseries.ui.EditcodeEditwordFormatter(); 
		formatter3.setEditCode('A');
		formatter3.setEditCodeParmType(EditcodeEditwordFormatter.EDITCODEPARM_NONE);
		AS400FieldModel fldModel3 = new com.ibm.etools.iseries.ui.AS400FieldModel(attributes3, formatter3);
		jftQuantity = new com.ibm.etools.iseries.ui.JFormattedTextField(fldModel3);
		jftQuantity.setBounds(143, 168, 104, 25);
		contentPane.add(jftQuantity);
		
		// Account No only accepts numeric, with edit mask "    -     "
		DataAttributes attributes4 = new DataAttributes(DataAttributes.DATATYPE_NUMERIC, 9);
		EditmaskAttributes editmask4 = new EditmaskAttributes("    -     ", "    &     ");
		AS400FieldModel fldModel4 = new AS400FieldModel(attributes4);
		jftAccount = new JFormattedTextField(fldModel4);
		jftAccount.setEditmaskAttributes(editmask4);
		jftAccount.setBounds(143, 214, 104, 25);
		contentPane.add(jftAccount);
		
		// Password field
		jPassword = new JPasswordField();
		jPassword.setBounds(143, 261, 104, 25);
		contentPane.add(jPassword);
		
		// Contact Phone only accepts numeric, with edit mask "(   )   -    "
		DataAttributes attributes5 = new DataAttributes(DataAttributes.DATATYPE_NUMERIC, 10);
		EditmaskAttributes editmask5 = new EditmaskAttributes("(   )   -    ", "&   &   &    ");
		AS400FieldModel fldModel5 = new AS400FieldModel(attributes5);
		jftPhone = new JFormattedTextField(fldModel5);
		jftPhone.setEditmaskAttributes(editmask5);
		jftPhone.setBounds(143, 308, 104, 25);
		contentPane.add(jftPhone);
	}
	catch (Exception ex)
	{
		ex.printStackTrace();
	}
	
	return contentPane;
}
/**
 * main entrypoint - starts the part when it is run as an application
 * @param args java.lang.String[]
 */
public static void main(java.lang.String[] args) {
	try {
		JFormattedTextFieldEquity aJFormattedTextFieldEquity;
		aJFormattedTextFieldEquity = new JFormattedTextFieldEquity();
		aJFormattedTextFieldEquity.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				System.exit(0);
			};
		});
		aJFormattedTextFieldEquity.show();
		aJFormattedTextFieldEquity.setVisible(true);
	} catch (Throwable exception) {
		System.err.println("Exception occurred in main()");
		exception.printStackTrace(System.out);
	}
}
}
