package com.ibm.etools.iseries.examples.objectList.memberList;

/**
 * Licensed Material - Property of IBM
 * (C) Copyright IBM Corp. 2002 - All Rights Reserved
 *
 * DISCLAIMER:
 * The following [enclosed] code is sample code created by IBM
 * Corporation.  This sample code is not part of any standard IBM product
 * and is provided to you solely for the purpose of assisting you in the
 * development of your applications.  The code is provided 'AS IS',
 * without warranty of any kind.  IBM shall not be liable for any damages
 * arising out of your use of the sample code, even if they have been
 * advised of the possibility of such damages.
 *
 * @version 1.0 02/02/02
 * @author Rick Sowa
 *
 * How to Run the objectList examples:
 *
 * 1) Run the example class. A dialog opens.
 * 2) Select or type the system name or TCP/IP address of the
 *    iSeries system you wish to connect to.
 * 3) Click GO.
 *    The default input data is collected into a search pattern
 *    string, and is then displayed on the right.
 *    A communications connection is established with the
 *    iSeries server, and a signon window opens. 
 * 4) Enter a User ID and a password. Click OK.
 *    The search pattern is then used to extract and subset a list
 *    of iSeries objects, and further data depending on the search
 *    requirements.  
 *    Finally, the retrieved list of data is displayed in the
 *    table.
 *    The number of items returned is also displayed above the search
 *    pattern field. So if 23 items were found and displayed in the
 *    table, the text would read: "Search Pattern, Found 23".
 *
 * 5) VARIATIONS
 *    Try selecting various types of lists by varying or selecting 
 *    the input properties. You can type in complete item names or
 *    generic names in order to get a subset of items. 
 *
 * 6) SUBSETTING
 *    Most input fields accept generic names with one * or two *s,
 *    such as "my*file*s".
 *    This allows you to search multiple files, libraries, or
 *    both, at one time.
 *
 * 7) MULTIPLE TYPES
 *    The "Type" input fields accept multiple entries.
 *    This allows you to retrieve multiple lists at one time.
 *    There are some samples of input data in the drop-down list
 *    showing the syntax to specify item TYPE and SUBTYPE.
 *
 * 8) GROWING MENU
 *    Each of the drop-down menus shows a list of sample input
 *    data which you can select. But you can also type in any new
 *    data names you prefer.
 *    All new names you type are saved in the drop-down
 *    menu, until the example is closed.
 *
 * 9) SWITCHING SERVERS
 *    The "iSeries name" field allows you to select an iSeries system
 *    to connect to when running the example.
 *    But you can also switch systems any time, by typing in a new
 *    system name.
 * 
 *10) RE_ORDER HEADINGS
 *    When the data is displayed in the table, you can drag the
 *    column headings to rearrange the order of the columns.
 *    You can also change the color of the table to look more like
 *    an iSeries display by pressing the button marked "Green".
 *    You can change it back with the "White" button.
 *
 *11) ERROR MESSAGES
 *    If an invalid or nonexistent iSeries system name is selected,
 *    the logon fails and the search pattern field 
 *    turns RED, and shows the invalid system name.
 *    If any other errors occur, a message may display in the search
 *    pattern field. Error messages may also be sent to STDOUT. 
 */
import java.awt.*;
import javax.swing.*;
public class MemberList extends JFrame {
	protected static java.awt.Toolkit rj = java.awt.Toolkit.getDefaultToolkit();
	public static String COLHEADMember = new String("Member");
	public static String COLHEADType = new String("Type");
	public static String COLHEADFileName = new String("File Name");
	public static String COLHEADFileType = new String("File Type");
	public static String COLHEADLibraryName = new String("Library");
	public static String COLHEADDescription = new String("Description");
	private JPanel ivjiSeriesListPane = null;
	private JPanel ivjJFrameContentPane = null;
	private JScrollPane ivjJScrollPane1 = null;
	private JTable ivjScrollPaneTable = null;
	private com.ibm.as400.access.AS400 ivjAS4001 = null;
	IvjEventHandler ivjEventHandler = new IvjEventHandler();
	private JTextField TextFieldFile = null;
	private JTextField TextFieldMember = null;
	private JTextField TextFieldWholeFilter = null;
	private JLabel ivjJLabel1 = null;
	private JLabel ivjJLabel2 = null;
	private JLabel ivjJLabel3 = null;
	private JLabel ivjJLabel4 = null;
	private JLabel ivjJLabel5 = null;
	private JLabel ivjJLabel6 = null;
	private JLabel ivjJLabel7 = null;
	private JLabel ivjJLabel8 = null;
	private JLabel ivjJLabel9 = null;
	private JComboBox ComboBoxServer = null;
	private JComboBox ComboBoxLibrary = null;
	private JComboBox ComboBoxMemberType = null;
	private JComboBox ComboBoxObjectType = null;
	private JButton ButtonGo = null;
	private JButton ButtonWhite = null;
	private JButton ButtonGreen = null;
	private JButton ButtonClose = null;
	public java.util.Vector ListTable = null;
	public java.util.Vector ColumnHeadings = null;
	private com.ibm.etools.iseries.comm.ISeriesListMembers ivjAS400ListMembers1 = null;
	private com.ibm.etools.iseries.comm.filters.ISeriesMemberFilterString ivjAS400MemberFilterString1 = null;

class IvjEventHandler implements java.awt.event.ActionListener {
		public void actionPerformed(java.awt.event.ActionEvent e) {
			if (e.getSource() == MemberList.this.getButtonGo())	{ 
				ActionGo1setSystemName(e);
				ActionGo2setFilters(e);
				ActionGo3getList(e);
				}
			if (e.getSource() == MemberList.this.getButtonGreen()) 
				ActionGreen(e);
			if (e.getSource() == MemberList.this.getButtonWhite()) 
				ActionWhite(e);
			if (e.getSource() == MemberList.this.getButtonClose()) 
				ActionClose(e);
		};
	};
/**
 * MemberList constructor comment.
 */
public MemberList() {
	super();
	initialize();
}
/**
 * MemberList constructor comment.
 * @param title java.lang.String
 */
public MemberList(String title) {
	super(title);
}
/**
 * Close the window. End program.
 * @param arg1 java.awt.event.ActionEvent
 */
private void ActionClose(java.awt.event.ActionEvent arg1) {
	try {
		this.dispose();
	} catch (java.lang.Throwable ivjExc) {
		handleException(ivjExc);
	}
}
/**
 * Set the iSeries system name to connect to.
 * @param arg1 java.awt.event.ActionEvent
 */
private void ActionGo1setSystemName(java.awt.event.ActionEvent arg1) {
	try {
		this.setCursor(new Cursor(Cursor.WAIT_CURSOR));
		rj.beep();
		getAS4001().setSystemName((String)getComboBoxServer().getSelectedItem());
		getAS400ListMembers1().setSystem(getAS4001());
		comboBoxAddTo(getComboBoxServer());
	} catch (java.lang.Throwable ivjExc) {
		String sn = null;
		sn = (String)getComboBoxServer().getSelectedItem();
		if( getAS4001().getSystemName().equalsIgnoreCase(sn))
			return;
		else	
			// cannot switch - 1st server active
			// reset connections
			getAS4001().resetAllServices();
			ivjAS400ListMembers1 = null;
			try	{
				getAS4001().setSystemName(sn);
				getAS400ListMembers1().setSystem(getAS4001());
				comboBoxAddTo(getComboBoxServer());
				return;
		 		}
			catch (java.lang.Throwable ivjExc2) {
	  			handleException(ivjExc2);
	   			}
		handleException(ivjExc);
	}
}
/**
 * Read the user's input selections
 * and set the filter string with:
 * Library name
 * File name
 * Member name
 * Member Type
 * File type.
 * @param arg1 java.awt.event.ActionEvent
 */
private void ActionGo2setFilters(java.awt.event.ActionEvent arg1) {
	try {
		getAS400MemberFilterString1().setLibrary((String)getComboBoxLibrary().getSelectedItem());
		comboBoxAddTo(getComboBoxLibrary());
		getAS400MemberFilterString1().setFile(getTextFieldFile().getText());
		getAS400MemberFilterString1().setMember(getTextFieldMember().getText());
		getAS400MemberFilterString1().setMemberType((String)getComboBoxMemberType().getSelectedItem());
		comboBoxAddTo(getComboBoxMemberType());
		getAS400MemberFilterString1().setObjectType((String)getComboBoxObjectType().getSelectedItem());
		comboBoxAddTo(getComboBoxObjectType());
		getTextFieldWholeFilter().setText(getAS400MemberFilterString1().toString());
	} catch (java.lang.Throwable ivjExc) {
		handleException(ivjExc);
	}
}
/**
 * Extract the list from the iSeries system.
 * Put the list into a table format for display.
 * @param arg1 java.awt.event.ActionEvent
 */
private void ActionGo3getList(java.awt.event.ActionEvent arg1) {
	java.util.List theList = null;
	try {
		theList = getAS400ListMembers1().getList(getAS400MemberFilterString1());
		buildTable(theList);
		getTextFieldWholeFilter().setBackground(java.awt.SystemColor.window);
		getTextFieldWholeFilter().setForeground(java.awt.SystemColor.windowText);
	} catch (java.lang.Throwable ivjExc) {
		handleException(ivjExc);
	}
	this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
	rj.beep();
}
/**
 * Change the table to historic iSeries Green
 * @param arg1 java.awt.event.ActionEvent
 */
private void ActionGreen(java.awt.event.ActionEvent arg1) {
	try {
		getScrollPaneTable().setBackground(java.awt.Color.black);
		getScrollPaneTable().setForeground(java.awt.Color.green);
	} catch (java.lang.Throwable ivjExc) {
		handleException(ivjExc);
	}
}
/**
 * Change the table to the usual White
 * @param arg1 java.awt.event.ActionEvent
 */
private void ActionWhite(java.awt.event.ActionEvent arg1) {
	try {
		getScrollPaneTable().setBackground(java.awt.SystemColor.window);
		getScrollPaneTable().setForeground(java.awt.SystemColor.windowText);
	} catch (java.lang.Throwable ivjExc) {
		handleException(ivjExc);
	}
}
/**
 * Build a table of data from the list vector.
 * Each element of the vector represents one member,
 * and each member has several attributes.
 * @param theList java.util.Vector
 */
private void buildTable(java.util.List theList) {
	try {
		// 1) For each element of the vector, extract all
		//    the attributes for that member and build one row. 
		java.util.Vector oneRowOfAttributes = null;
		int size = theList.size();
		ListTable = new java.util.Vector();
		com.ibm.etools.iseries.comm.interfaces.IISeriesHostObjectBasic currRecord = null;
		int idx = 0;
		for (idx = 0; idx < size; idx++) {
			oneRowOfAttributes = new java.util.Vector(6);
			currRecord = (com.ibm.etools.iseries.comm.interfaces.IISeriesHostObjectBasic)theList.get(idx);
			oneRowOfAttributes.addElement(currRecord.getName());
			oneRowOfAttributes.addElement(currRecord.getType());
			oneRowOfAttributes.addElement(currRecord.getFile());
			oneRowOfAttributes.addElement(currRecord.getSubType());
			oneRowOfAttributes.addElement(currRecord.getLibrary());
			oneRowOfAttributes.addElement(currRecord.getDescription());
			ListTable.addElement(oneRowOfAttributes);
			}
		// display the number of items
		getJLabel9().setText( new Integer(idx).toString() );

		// 2) Build the column headings for the table
		ColumnHeadings = new java.util.Vector();
		ColumnHeadings.addElement(COLHEADMember);
		ColumnHeadings.addElement(COLHEADType);
		ColumnHeadings.addElement(COLHEADFileName);
		ColumnHeadings.addElement(COLHEADFileType);
		ColumnHeadings.addElement(COLHEADLibraryName);
		ColumnHeadings.addElement(COLHEADDescription);
  
		// 3) Create the table, with the data
		javax.swing.table.DefaultTableModel TM =
			new javax.swing.table.DefaultTableModel(ListTable, ColumnHeadings);
	
		// 4) Re-size the columns, and repaint
		getScrollPaneTable().setModel(TM);
		String	dname = null;
		dname = COLHEADMember;
		getScrollPaneTable().getColumn( dname ).setMinWidth( 90 );
		dname = COLHEADType;
		getScrollPaneTable().getColumn( dname ).setMinWidth( 40 );
		dname = COLHEADFileName;
		getScrollPaneTable().getColumn( dname ).setMinWidth( 90 );
		dname = COLHEADFileType;
		getScrollPaneTable().getColumn( dname ).setMinWidth( 40 );
		dname = COLHEADLibraryName;
		getScrollPaneTable().getColumn( dname ).setMinWidth( 90 );
		dname = COLHEADDescription;
		getScrollPaneTable().getColumn( dname ).setMinWidth( 400 );
		// Turn the Horizontal scroll bar ON
		getScrollPaneTable().setAutoResizeMode( javax.swing.JTable.AUTO_RESIZE_OFF);
		// Force the column widths to resize and repaint
		getScrollPaneTable().sizeColumnsToFit( 4 );
	} catch (java.lang.Throwable ivjExc) {
		handleException(ivjExc);
	}
}
/**
 * Add new items to the comboBox.
 * @param javax.swing.JComboBox
 */
private void comboBoxAddTo(javax.swing.JComboBox CB) {
	try {
		if (CB.getSelectedIndex() < 0) // a new item
			CB.insertItemAt(CB.getSelectedItem(),0);
	} catch (java.lang.Throwable ivjExc) {
		handleException(ivjExc);
	}
}
/**
 * Return the ivjAS4001 property value.
 * @return com.ibm.as400.access.AS400
 */
private com.ibm.as400.access.AS400 getAS4001() {
	if (ivjAS4001 == null) {
		try {
			ivjAS4001 = new com.ibm.as400.access.AS400();
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjAS4001;
}
/**
 * Return the AS400ListMembers1 property value.
 * @return com.ibm.etools.iseries.comm.ISeriesListMembers
 */
private com.ibm.etools.iseries.comm.ISeriesListMembers getAS400ListMembers1() {
	if (ivjAS400ListMembers1 == null) {
		try {
			ivjAS400ListMembers1 = new com.ibm.etools.iseries.comm.ISeriesListMembers();
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjAS400ListMembers1;
}
/**
 * Return the AS400MemberFilterString1 property value.
 * @return com.ibm.etools.iseries.comm.filters.ISeriesMemberFilterString
 */
private com.ibm.etools.iseries.comm.filters.ISeriesMemberFilterString getAS400MemberFilterString1() {
	if (ivjAS400MemberFilterString1 == null) {
		try {
			ivjAS400MemberFilterString1 = new com.ibm.etools.iseries.comm.filters.ISeriesMemberFilterString();
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjAS400MemberFilterString1;
}
/**
 * Return the ButtonClose property value.
 * @return javax.swing.JButton
 */
private javax.swing.JButton getButtonClose() {
	if (ButtonClose == null) {
		try {
			ButtonClose = new javax.swing.JButton();
			ButtonClose.setName("ButtonClose");
			ButtonClose.setText("Close");
			ButtonClose.setBounds(649, 543, 85, 25);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ButtonClose;
}
/**
 * Return ButtonGo.
 * @return javax.swing.JButton
 */
private javax.swing.JButton getButtonGo() {
	if (ButtonGo == null) {
		try {
			ButtonGo = new javax.swing.JButton();
			ButtonGo.setName("ButtonGo");
			ButtonGo.setFont(new java.awt.Font("Arial", 1, 36));
			ButtonGo.setText("GO");
			ButtonGo.setBackground(java.awt.Color.green);
			ButtonGo.setBounds(343, 50, 185, 59);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ButtonGo;
}
/**
 * Return the ButtonGreen property value.
 * @return javax.swing.JButton
 */
private javax.swing.JButton getButtonGreen() {
	if (ButtonGreen == null) {
		try {
			ButtonGreen = new javax.swing.JButton();
			ButtonGreen.setName("ButtonGreen");
			ButtonGreen.setText("Green");
			ButtonGreen.setBounds(505, 543, 85, 25);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ButtonGreen;
}
/**
 * Return the ButtonWhite property value.
 * @return javax.swing.JButton
 */
private javax.swing.JButton getButtonWhite() {
	if (ButtonWhite == null) {
		try {
			ButtonWhite = new javax.swing.JButton();
			ButtonWhite.setName("ButtonWhite");
			ButtonWhite.setText("White");
			ButtonWhite.setBounds(361, 543, 85, 25);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ButtonWhite;
}
/**
 * Return the ComboBoxLibrary property value.
 * @return javax.swing.JComboBox
 */
private javax.swing.JComboBox getComboBoxLibrary() {
	if (ComboBoxLibrary == null) {
		try {
			ComboBoxLibrary = new javax.swing.JComboBox();
			ComboBoxLibrary.setName("ComboBoxLibrary");
			ComboBoxLibrary.setBounds(126, 66, 130, 23);
			ComboBoxLibrary.setEditable(true);
			ComboBoxLibrary.addItem("*USRLIBL");
			ComboBoxLibrary.addItem("*LIBL");
			ComboBoxLibrary.addItem("*CURLIB");
			ComboBoxLibrary.addItem("*ALL");
			ComboBoxLibrary.addItem("*ALLUSR");
			ComboBoxLibrary.addItem("ADTSLAB");
			ComboBoxLibrary.addItem("QGPL");
			ComboBoxLibrary.addItem("S*");
			ComboBoxLibrary.addItem("Q*G*");
			ComboBoxLibrary.addItem("A*S*");
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ComboBoxLibrary;
}
/**
 * Return the ComboBoxMemberType property value.
 * @return javax.swing.JComboBox
 */
private javax.swing.JComboBox getComboBoxMemberType() {
	if (ComboBoxMemberType == null) {
		try {
			ComboBoxMemberType = new javax.swing.JComboBox();
			ComboBoxMemberType.setName("ComboBoxMemberType");
			ComboBoxMemberType.setBounds(126, 130, 130, 23);
			ComboBoxMemberType.setEditable(true);
			ComboBoxMemberType.addItem("*ALL");
			ComboBoxMemberType.addItem("C");
			ComboBoxMemberType.addItem("CBL");
			ComboBoxMemberType.addItem("CMD");
			ComboBoxMemberType.addItem("DSPF");
			ComboBoxMemberType.addItem("DSPF MNUDDS");
			ComboBoxMemberType.addItem("LF");
			ComboBoxMemberType.addItem("LF38");
			ComboBoxMemberType.addItem("MENU");
			ComboBoxMemberType.addItem("MNU");
			ComboBoxMemberType.addItem("MNUCMD");
			ComboBoxMemberType.addItem("MNUDDS");
			ComboBoxMemberType.addItem("PF");
			ComboBoxMemberType.addItem("PF38");
			ComboBoxMemberType.addItem("PLI");
			ComboBoxMemberType.addItem("PLI38");
			ComboBoxMemberType.addItem("PNLGRP");
			ComboBoxMemberType.addItem("PRTF");
			ComboBoxMemberType.addItem("PRTF38");
			ComboBoxMemberType.addItem("QRY38");
			ComboBoxMemberType.addItem("REXX");
			ComboBoxMemberType.addItem("RPG");
			ComboBoxMemberType.addItem("RPGLE");
			ComboBoxMemberType.addItem("RPG38");
			/*ComboBoxMemberType.addItem("*ALL");
			ComboBoxMemberType.addItem("*BLANK");
			ComboBoxMemberType.addItem("BAS");
			ComboBoxMemberType.addItem("BAS36");
			ComboBoxMemberType.addItem("BAS38");
			ComboBoxMemberType.addItem("BASP");
			ComboBoxMemberType.addItem("BASP38");
			ComboBoxMemberType.addItem("C");
			ComboBoxMemberType.addItem("CBL");
			ComboBoxMemberType.addItem("CBLLE");
			ComboBoxMemberType.addItem("CBL36");
			ComboBoxMemberType.addItem("CBL38");
			ComboBoxMemberType.addItem("CICSC");
			ComboBoxMemberType.addItem("CICSCBL");
			ComboBoxMemberType.addItem("CICSCBLLE");
			ComboBoxMemberType.addItem("CICSMAP");
			ComboBoxMemberType.addItem("CICSSQLCBL");
			ComboBoxMemberType.addItem("CLD");
			ComboBoxMemberType.addItem("CLLE");
			ComboBoxMemberType.addItem("CLP");
			ComboBoxMemberType.addItem("CLP38");
			ComboBoxMemberType.addItem("CMD");
			ComboBoxMemberType.addItem("DSPF");
			ComboBoxMemberType.addItem("DSPF36");
			ComboBoxMemberType.addItem("DSPF38");
			ComboBoxMemberType.addItem("FTN");
			ComboBoxMemberType.addItem("ICFF");
			ComboBoxMemberType.addItem("LF");
			ComboBoxMemberType.addItem("LF38");
			ComboBoxMemberType.addItem("MENU");
			ComboBoxMemberType.addItem("MNU");
			ComboBoxMemberType.addItem("MNUCMD");
			ComboBoxMemberType.addItem("MNUDDS");
			ComboBoxMemberType.addItem("MNU36");
			ComboBoxMemberType.addItem("MSGF36");
			ComboBoxMemberType.addItem("OCL36");
			ComboBoxMemberType.addItem("PAS");
			ComboBoxMemberType.addItem("PF");
			ComboBoxMemberType.addItem("PF38");
			ComboBoxMemberType.addItem("PLI");
			ComboBoxMemberType.addItem("PLI38");
			ComboBoxMemberType.addItem("PNLGRP");
			ComboBoxMemberType.addItem("PRTF");
			ComboBoxMemberType.addItem("PRTF38");
			ComboBoxMemberType.addItem("QRY38");
			ComboBoxMemberType.addItem("REXX");
			ComboBoxMemberType.addItem("RMC");
			ComboBoxMemberType.addItem("RPG");
			ComboBoxMemberType.addItem("RPGLE");
			ComboBoxMemberType.addItem("RPG36");
			ComboBoxMemberType.addItem("RPG38");
			ComboBoxMemberType.addItem("RPT");
			ComboBoxMemberType.addItem("RPT36");
			ComboBoxMemberType.addItem("RPT38");
			ComboBoxMemberType.addItem("SPADCT");
			ComboBoxMemberType.addItem("SQLC");
			ComboBoxMemberType.addItem("SQLCBL");
			ComboBoxMemberType.addItem("SQLCBLLE");
			ComboBoxMemberType.addItem("SQLFTN");
			ComboBoxMemberType.addItem("SQLPLI");
			ComboBoxMemberType.addItem("SQLRPG");
			ComboBoxMemberType.addItem("SQLRPGLE");
			ComboBoxMemberType.addItem("TBL");
			ComboBoxMemberType.addItem("TXT");
			*/
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ComboBoxMemberType;
}
/**
 * Return the ComboBoxObjectType property value.
 * @return javax.swing.JComboBox
 */
private javax.swing.JComboBox getComboBoxObjectType() {
	if (ComboBoxObjectType == null) {
		try {
			ComboBoxObjectType = new javax.swing.JComboBox();
			ComboBoxObjectType.setName("ComboBoxObjectType");
			ComboBoxObjectType.setBounds(126, 152, 130, 23);
			ComboBoxObjectType.setEditable(true);
			ComboBoxObjectType.addItem("*FILE:PF-SRC");
			ComboBoxObjectType.addItem("*FILE:PF-DTA");
			ComboBoxObjectType.addItem("*FILE:PF");
			ComboBoxObjectType.addItem("*FILE:LF");
			ComboBoxObjectType.addItem("*FILE:DDMF");
			ComboBoxObjectType.addItem("*FILE:PF-SRC *FILE:PF-DTA");
			ComboBoxObjectType.addItem("*FILE:PF *FILE:LF");
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ComboBoxObjectType;
}
/**
 * Return the ComboBoxServer property value.
 * @return javax.swing.JComboBox
 */
private javax.swing.JComboBox getComboBoxServer() {
	if (ComboBoxServer == null) {
		try {
			ComboBoxServer = new javax.swing.JComboBox();
			ComboBoxServer.setName("ComboBoxServer");
			ComboBoxServer.setBounds(126, 46, 130, 23);
			ComboBoxServer.setEditable(true);
			ComboBoxServer.addItem("iSeries01");
			ComboBoxServer.addItem("COMMON");
			ComboBoxServer.addItem("1.1.1.1");
			ComboBoxServer.addItem("system01");
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ComboBoxServer;
}
/**
 * Return the iSeriesListPane property value.
 * @return javax.swing.JPanel
 */
private javax.swing.JPanel getiSeriesListPane() {
	if (ivjiSeriesListPane == null) {
		try {
			ivjiSeriesListPane = new javax.swing.JPanel();
			ivjiSeriesListPane.setName("iSeriesListPane");
			ivjiSeriesListPane.setLayout(null);
			getiSeriesListPane().add(getJScrollPane1(), getJScrollPane1().getName());
			getiSeriesListPane().add(getJLabel1(), getJLabel1().getName());
			getiSeriesListPane().add(getJLabel2(), getJLabel2().getName());
			getiSeriesListPane().add(getJLabel3(), getJLabel3().getName());
			getiSeriesListPane().add(getJLabel4(), getJLabel4().getName());
			getiSeriesListPane().add(getJLabel5(), getJLabel5().getName());
			getiSeriesListPane().add(getJLabel6(), getJLabel6().getName());
			getiSeriesListPane().add(getJLabel7(), getJLabel7().getName());
			getiSeriesListPane().add(getJLabel8(), getJLabel8().getName());
			getiSeriesListPane().add(getJLabel9(), getJLabel9().getName());
			getiSeriesListPane().add(getComboBoxServer(), getComboBoxServer().getName());
			getiSeriesListPane().add(getComboBoxLibrary(), getComboBoxLibrary().getName());
			getiSeriesListPane().add(getTextFieldFile(), getTextFieldFile().getName());
			getiSeriesListPane().add(getTextFieldMember(), getTextFieldMember().getName());
			getiSeriesListPane().add(getComboBoxMemberType(), getComboBoxMemberType().getName());
			getiSeriesListPane().add(getComboBoxObjectType(), getComboBoxObjectType().getName());
			getiSeriesListPane().add(getTextFieldWholeFilter(), getTextFieldWholeFilter().getName());
			getiSeriesListPane().add(getButtonGo(), getButtonGo().getName());
			getiSeriesListPane().add(getButtonWhite(), getButtonWhite().getName());
			getiSeriesListPane().add(getButtonGreen(), getButtonGreen().getName());
			getiSeriesListPane().add(getButtonClose(), getButtonClose().getName());
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjiSeriesListPane;
}
/**
 * Return the JFrameContentPane property value.
 * @return javax.swing.JPanel
 */
private javax.swing.JPanel getJFrameContentPane() {
	if (ivjJFrameContentPane == null) {
		try {
			ivjJFrameContentPane = new javax.swing.JPanel();
			ivjJFrameContentPane.setName("JFrameContentPane");
			ivjJFrameContentPane.setLayout(new java.awt.BorderLayout());
			getJFrameContentPane().add(getiSeriesListPane(), "Center");
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJFrameContentPane;
}
/**
 * Return the JLabel1 property value.
 * @return javax.swing.JLabel
 */
private javax.swing.JLabel getJLabel1() {
	if (ivjJLabel1 == null) {
		try {
			ivjJLabel1 = new javax.swing.JLabel();
			ivjJLabel1.setName("JLabel1");
			ivjJLabel1.setText("iSeries Name");
			ivjJLabel1.setBounds(38, 49, 90, 14);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJLabel1;
}
/**
 * Return the JLabel2 property value.
 * @return javax.swing.JLabel
 */
private javax.swing.JLabel getJLabel2() {
	if (ivjJLabel2 == null) {
		try {
			ivjJLabel2 = new javax.swing.JLabel();
			ivjJLabel2.setName("JLabel2");
			ivjJLabel2.setText("Library");
			ivjJLabel2.setBounds(38, 69, 90, 14);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJLabel2;
}
/**
 * Return the JLabel3 property value.
 * @return javax.swing.JLabel
 */
private javax.swing.JLabel getJLabel3() {
	if (ivjJLabel3 == null) {
		try {
			ivjJLabel3 = new javax.swing.JLabel();
			ivjJLabel3.setName("JLabel3");
			ivjJLabel3.setText("File Name");
			ivjJLabel3.setBounds(38, 90, 90, 14);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJLabel3;
}
/**
 * Return the JLabel4 property value.
 * @return javax.swing.JLabel
 */
private javax.swing.JLabel getJLabel4() {
	if (ivjJLabel4 == null) {
		try {
			ivjJLabel4 = new javax.swing.JLabel();
			ivjJLabel4.setName("JLabel4");
			ivjJLabel4.setText("Member Types");
			ivjJLabel4.setBounds(38, 135, 90, 14);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJLabel4;
}
/**
 * Return the JLabel5 property value.
 * @return javax.swing.JLabel
 */
private javax.swing.JLabel getJLabel5() {
	if (ivjJLabel5 == null) {
		try {
			ivjJLabel5 = new javax.swing.JLabel();
			ivjJLabel5.setName("JLabel5");
			ivjJLabel5.setText("Member Name");
			ivjJLabel5.setBounds(38, 112, 90, 14);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJLabel5;
}
/**
 * Return the JLabel6 property value.
 * @return javax.swing.JLabel
 */
private javax.swing.JLabel getJLabel6() {
	if (ivjJLabel6 == null) {
		try {
			ivjJLabel6 = new javax.swing.JLabel();
			ivjJLabel6.setName("JLabel6");
			ivjJLabel6.setText("Search Filter, Found");
			ivjJLabel6.setBounds(343, 136, 144, 14);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJLabel6;
}
/**
 * Return the JLabel7 property value.
 * @return javax.swing.JLabel
 */
private javax.swing.JLabel getJLabel7() {
	if (ivjJLabel7 == null) {
		try {
			ivjJLabel7 = new javax.swing.JLabel();
			ivjJLabel7.setName("JLabel7");
			ivjJLabel7.setFont(new java.awt.Font("Arial", 1, 36));
			ivjJLabel7.setText("MEMBER LIST Searches for iSeries DEMO");
			ivjJLabel7.setBounds(39, 9, 729, 34);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJLabel7;
}
/**
 * Return the JLabel8 property value.
 * @return javax.swing.JLabel
 */
private javax.swing.JLabel getJLabel8() {
	if (ivjJLabel8 == null) {
		try {
			ivjJLabel8 = new javax.swing.JLabel();
			ivjJLabel8.setName("JLabel8");
			ivjJLabel8.setText("File Types");
			ivjJLabel8.setBounds(38, 158, 83, 14);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJLabel8;
}
/**
 * Return the JLabel9 property value.
 * @return javax.swing.JLabel
 */
private javax.swing.JLabel getJLabel9() {
	if (ivjJLabel9 == null) {
		try {
			ivjJLabel9 = new javax.swing.JLabel();
			ivjJLabel9.setName("JLabel9");
			ivjJLabel9.setText("0");
			ivjJLabel9.setBounds(460, 136, 144, 14);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJLabel9;
}
/**
 * Return the JScrollPane1 property value.
 * @return javax.swing.JScrollPane
 */
private javax.swing.JScrollPane getJScrollPane1() {
	if (ivjJScrollPane1 == null) {
		try {
			ivjJScrollPane1 = new javax.swing.JScrollPane();
			ivjJScrollPane1.setName("JScrollPane1");
			ivjJScrollPane1.setVerticalScrollBarPolicy(javax.swing.JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
			ivjJScrollPane1.setHorizontalScrollBarPolicy(javax.swing.JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);
			ivjJScrollPane1.setBounds(38, 179, 724, 357);
			getJScrollPane1().setViewportView(getScrollPaneTable());
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjJScrollPane1;
}
/**
 * Return the ScrollPaneTable property value.
 * @return javax.swing.JTable
 */
private javax.swing.JTable getScrollPaneTable() {
	if (ivjScrollPaneTable == null) {
		try {
			ivjScrollPaneTable = new javax.swing.JTable();
			ivjScrollPaneTable.setName("ScrollPaneTable");
			getJScrollPane1().setColumnHeaderView(ivjScrollPaneTable.getTableHeader());
			ivjScrollPaneTable.setBounds(0, 0, 200, 200);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return ivjScrollPaneTable;
}
/**
 * Return the TextFieldFile property value.
 * @return javax.swing.JTextField
 */
private javax.swing.JTextField getTextFieldFile() {
	if (TextFieldFile == null) {
		try {
			TextFieldFile = new javax.swing.JTextField();
			TextFieldFile.setName("TextFieldFile");
			TextFieldFile.setText("*");
			TextFieldFile.setBounds(126, 88, 130, 23);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return TextFieldFile;
}
/**
 * Return the TextFieldMember property value.
 * @return javax.swing.JTextField
 */
private javax.swing.JTextField getTextFieldMember() {
	if (TextFieldMember == null) {
		try {
			TextFieldMember = new javax.swing.JTextField();
			TextFieldMember.setName("TextFieldMember");
			TextFieldMember.setText("*");
			TextFieldMember.setBounds(126, 110, 130, 23);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return TextFieldMember;
}
/**
 * Return the TextFieldWholeFilter property value.
 * @return javax.swing.JTextField
 */
private javax.swing.JTextField getTextFieldWholeFilter() {
	if (TextFieldWholeFilter == null) {
		try {
			TextFieldWholeFilter = new javax.swing.JTextField();
			TextFieldWholeFilter.setName("TextFieldWholeFilter");
			TextFieldWholeFilter.setBounds(343, 153, 418, 20);
			TextFieldWholeFilter.setEditable(false);
		} catch (java.lang.Throwable ivjExc) {
			handleException(ivjExc);
		}
	}
	return TextFieldWholeFilter;
}
/**
 * Called whenever the part throws an exception.
 * @param exception java.lang.Throwable
 */
private void handleException(java.lang.Throwable exception) {
	String msg = exception.getMessage();
	System.out.println(	msg );
	if (msg == null)
		msg = "CANCELED - NO LIST RETURNED";
	getTextFieldWholeFilter().setText( msg );
	getTextFieldWholeFilter().setBackground(java.awt.Color.red);
	getTextFieldWholeFilter().setForeground(java.awt.Color.white);
	this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
	rj.beep();
}
/**
 * Initializes connections
 */
private void initConnections() throws java.lang.Exception {
	getButtonGo().addActionListener(ivjEventHandler);
	getButtonWhite().addActionListener(ivjEventHandler);
	getButtonGreen().addActionListener(ivjEventHandler);
	getButtonClose().addActionListener(ivjEventHandler);
}
/**
 * Initialize the class.
 */
private void initialize() {
	try {
		setName("MemberList");
		setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		setSize(798, 601);
		setTitle("MemberList");
		setContentPane(getJFrameContentPane());
		initConnections();
	} catch (java.lang.Throwable ivjExc) {
		handleException(ivjExc);
	}
}
/**
 * Starts the application.
 * @param args an array of command-line arguments
 */
public static void main(java.lang.String[] args) {
	try {
		/* Set native look and feel */
		UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());

		/* Create the frame */
		MemberList aMemberList = new MemberList();

		/* Calculate the screen size */
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();

		/* Add a windowListener for the windowClosedEvent */
		aMemberList.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosed(java.awt.event.WindowEvent e) {
				System.exit(0);
			};
		});
		aMemberList.setVisible(true);
	} catch (Throwable exception) {
		System.err.println("Exception occurred in main() of MemberList");
		exception.printStackTrace(System.out);
	}
}
}
