package com.ibm.etools.iseries.examples.toolbox;


/////////////////////////////////////////////////////////////////////////
// Example that shows listing all spooled files on a system Synchronously.
// Listing Synchronously does not return to the caller until the complete list
// is built. The user perceives a slower response time then listing Asynchronously.
//
// For more information about AS/400 Printing, refer to :
//   OS/400 Printer Device Programming, SC41-3713
//   IBM AS/400 Printing IV Redbook, GG24-4389
//
/////////////////////////////////////////////////////////////////////////
//
// This source is an example of AS/400 Toolbox for Java "PrintObjectList".
// IBM grants you a nonexclusive license to use this as an example
// from which you can generate similar function tailored to
// your own specific needs.
//
// This sample code is provided by IBM for illustrative purposes
// only. These examples have not been thoroughly tested under all
// conditions. IBM, therefore, cannot guarantee or imply
// reliability, serviceability, or function of these programs.
//
// All programs contained herein are provided to you "AS IS"
// without any warranties of any kind.  The implied warranties of
// merchantablility and fitness for a particular purpose are
// expressly disclaimed.
//
// AS/400 Toolbox for Java
// (C) Copyright IBM Corp. 1997
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
//
/////////////////////////////////////////////////////////////////////////


import java.util.Enumeration;


import com.ibm.as400.access.AS400;
import com.ibm.as400.access.SpooledFileList;
import com.ibm.as400.access.SpooledFile;


public class NPExampleListSplfSynch
{
	private AS400 system_ = new AS400();


	public NPExampleListSplfSynch(AS400 system)
	{
		system_ = system;
	}
	public void listSpooledFiles()
	{
		try{
			String strSpooledFileName;


			if( system_ == null )
			{
				system_ = new AS400();
			}


			System.out.println(" Now receiving all spooled files Synchronously");


			SpooledFileList splfList = new SpooledFileList( system_ );


			// set filters, all users, on all queues
			splfList.setUserFilter("*ALL");
			splfList.setQueueFilter("/QSYS.LIB/%ALL%.LIB/%ALL%.OUTQ");


			// open list, openSynchronously() returns when the list is completed.
			splfList.openSynchronously();
			Enumeration enum = splfList.getObjects();


			while( enum.hasMoreElements() )
			{
				SpooledFile splf = (SpooledFile)enum.nextElement();
				if ( splf != null )
				{
					// output this spooled file's name
					strSpooledFileName = splf.getStringAttribute(SpooledFile.ATTR_SPOOLFILE);
					System.out.println(" spooled file = " + strSpooledFileName);
				}
			}
			// clean up after we are done with the list
			splfList.close();
		}
		catch( Exception e )
		{
			// ...handle any exceptions...
			e.printStackTrace();
		}
	}
	public static void main( String args[] )
	{
		NPExampleListSplfSynch list = new NPExampleListSplfSynch(new AS400());
		try{
			list.listSpooledFiles();
		}
		catch( Exception e )
		{
			e.printStackTrace();
		}
		System.exit(0);
	}
}
