package com.ibm.etools.iseries.examples.toolboxdemo;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 1997, 1998 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if they have been
// advised of the possibility of such damages.


// This class extends JPanel.  It illustrates the use of job-related
// classes in the Toolbox.


import java.awt.Component;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import com.ibm.as400.access.AS400;
import com.ibm.as400.vaccess.AS400DetailsPane;
import com.ibm.as400.vaccess.AS400ExplorerPane;
import com.ibm.as400.vaccess.ErrorDialogAdapter;
import com.ibm.as400.vaccess.VJob;
import com.ibm.as400.vaccess.VJobList;


public class JobExample extends JPanel implements ActionListener{


private ToolboxDemo		parentFrame;


// Labels and text fields:
private JLabel			l0=new JLabel("This panel demonstrates the use of Job-related Toolbox classes");
private JLabel			l1=new JLabel("AS400:");
private JLabel			l2=new JLabel("User:");
private JLabel			l3=new JLabel("Job name:");
private JLabel			l4=new JLabel("Job #:");
private JTextField		t1=new JTextField();
private JTextField		t2=new JTextField("*ALL");
private JTextField		t3=new JTextField("*ALL");
private JTextField		t4=new JTextField("*ALL");


// Pushbuttons:
private JButton		populatePB=new JButton("Refresh");
private JButton		jobPB=new JButton("Job log");


// VAccess controls
private AS400ExplorerPane	explorerPane=new AS400ExplorerPane();
private AS400DetailsPane	detailsPane=new AS400DetailsPane();
private VJobList			jobList;


public AS400 				AS400Connection=new AS400();


// This error handler is shared by all components.
private static ErrorDialogAdapter errorHandler;
































// Constructor
public JobExample(ToolboxDemo t) {
	parentFrame=t;


	t1=new JTextField(parentFrame.AS400Name,9);
	populatePB.setToolTipText("Populate ExplorerPane with AS/400 Job information");
	jobPB.setToolTipText("Populate DetailsPane with selected Object");
	explorerPane.setToolTipText("ExplorerPane, displays selected joblist");
	detailsPane.setToolTipText("DetailsPane, displays selected job log");
	JPanel p = new JPanel();
	p.setLayout(new GridLayout(1, 8, 0, 6));
	p.add(l1); p.add(t1);
	p.add(l2); p.add(t2);
	p.add(l3); p.add(t3);
	p.add(l4); p.add(t4);


	JPanel p1 = new JPanel();
	p1.setLayout(new GridLayout(1, 2, 0, 6));
	p1.add(populatePB);
	p1.add(jobPB);
	
	explorerPane.setPreferredSize(new Dimension(700,180));
	explorerPane.setMinimumSize(new Dimension(400,160));
	detailsPane.setPreferredSize(new Dimension(700,240));
	detailsPane.setMinimumSize(new Dimension(400,200));


	// Set up listeners
	populatePB.addActionListener(this);
	jobPB.addActionListener(this);


	// Show any errors to the user.
	errorHandler = new ErrorDialogAdapter (parentFrame);




	// Position items on pane
	setLayout(new GridBagLayout());
	addit1(l0,0,0,10,1,
		java.awt.GridBagConstraints.HORIZONTAL,java.awt.GridBagConstraints.NORTHWEST,
		10,1,1,1,1,1);
	addit1(p,0,1,10,1,
		java.awt.GridBagConstraints.HORIZONTAL,java.awt.GridBagConstraints.NORTHWEST,
		10,1,1,1,1,1);
	addit1(p1,0,2,10,1,
		java.awt.GridBagConstraints.NONE,java.awt.GridBagConstraints.CENTER,
		10,1,1,1,1,1);
	addit1(explorerPane,0,3,10,2,
		java.awt.GridBagConstraints.BOTH,java.awt.GridBagConstraints.NORTHWEST,
		10,10,1,1,1,1);
	addit1(detailsPane,0,5,10,2,
		java.awt.GridBagConstraints.BOTH,java.awt.GridBagConstraints.NORTHWEST,
		10,10,1,1,1,1);
}
public void actionPerformed(ActionEvent e) {
	try {
		if(e.getSource() == populatePB) {
	 		// Populate all panes with User List from specified AS/400
			parentFrame.status.setText("Retrieving job list from "+t1.getText()+ " ....");
			AS400Connection= new AS400(t1.getText().trim());
			AS400Connection.connectService(AS400.FILE);
			jobList = new VJobList (AS400Connection);
			jobList.setUser(t2.getText().trim());
			jobList.setName(t3.getText().trim());
			jobList.setNumber(t4.getText().trim());
			parentFrame.status.setText("Updating panes ....");
			explorerPane.setRoot(jobList);
			explorerPane.setAllowActions(true);
			explorerPane.load();
			parentFrame.status.setText("Idle");
	  	} else if(e.getSource() == jobPB) {
		  	Object o=explorerPane.getSelectedObject();
		  	if ( o != null) {
			  	VJob job=(VJob)o;
			  	detailsPane.setRoot(job);
			  	detailsPane.load();
		  	} else {
			  	detailsPane.setRoot(new VJob());
			  	detailsPane.load();
		  	}
	  	}


   } catch(Exception e1) {
	   System.out.println("Exception:"+e1.getMessage());
	   e1.printStackTrace();
   }
}
// add Component to JPanel, using passed GridbagLayout - related values
private void addit1(Component c, int x, int y, int xw, int yw,
						int fill, int anchor, double weightx, double weighty,
						int top, int left, int bottom, int right) {
	GridBagConstraints gbc = new GridBagConstraints();
	gbc.gridx=x;
	gbc.gridy=y;
	gbc.gridwidth=xw;
	gbc.gridheight=yw;
	gbc.fill=fill;
	gbc.anchor=anchor;
	gbc.weightx=weightx;
	gbc.weighty=weighty;
	if (top+bottom+left+right > 0)
		gbc.insets = new Insets(top, left, bottom, right);
	// Set constraint for the component
	((GridBagLayout)getLayout()).setConstraints(c, gbc);
	add(c);
}
}
